==> mtc-core-v0.1.4-601762.tar: src/Providers/CoreServiceProvider.php <==
<?php
/**
 * Core Service Provider
 *
 * PHP Version 7
 *
 * @category Mtc\Core\Providers
 * @package  Mtc\Core\Admin
 * @author   Craig McCreath <craig.mccreath@mtcmedia.co.uk>
 */

namespace Mtc\Core\Providers;

use App;
use Cache;
use Event;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\ServiceProvider;
use Mtc\Core\Node;
use Mtc\Core\Core;
use Mtc\Core\Http\ViewComposers\EntrustComposer;
use Mtc\Core\Listeners\DeleteCustomData;
use Mtc\Core\Listeners\DeleteNode;
use Mtc\Core\Listeners\SaveCustomData;
use Mtc\Core\Listeners\ValidateMtcLogin;
use View;

/**
 * Connect Core to Laravel, registering routes and services that require access.
 *
 * @category Mtc\Core\Providers
 * @package  Mtc\Core\Admin
 * @author   Craig McCreath <craig.mccreath@mtcmedia.co.uk>
 */
class CoreServiceProvider extends ServiceProvider
{
    /**
     * Boot the service provider.
     *
     * @return void
     */
    public function boot()
    {
        $this->defineRoutes();
        $this->defineResources();
        $this->definePublished();

        // Define a custom 'transpose' macro for Collections.
        Collection::macro(
            'transpose', function () {
                $items = array_map(
                    function (...$items) {
                        return $items;
                    }, ...$this->values()
                );

                return new static($items);
            }
        );
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        if (! defined('CORE_PATH')) {
            define('CORE_PATH', realpath(__DIR__.'/../../'));
        }

        if (! class_exists('Core')) {
            class_alias(Core::class, 'Core');
        }

        if ($this->app->runningInConsole()) {
            $this->commands([]);
        }

        // Register the Laravel debug bar when not production
        if ($this->app->environment('production') === false) {
            $this->app->register('Barryvdh\Debugbar\ServiceProvider');
        }

        $this->registerComponents();
    }

    /**
     * Define the routes.
     *
     * @return void
     */
    protected function defineRoutes()
    {
        $this->defineRouteBindings();

        /**
         * If the routes have not been cached, we will include them in a route group
         * so that all of the routes will be conveniently registered to the given
         * controller namespace. After that we will load the Core routes file.
         */
        if (! $this->app->routesAreCached()) {
            Route::group(
                ['namespace' => 'Mtc\Core\Http\Controllers'],
                function ($router) {
                    $path = realpath(CORE_PATH . '/routes');
                    foreach (glob("{$path}/*.php") as $file) {
                        include $file;
                    }
                }
            );
        }
    }

    /**
     * Define the route model bindings.
     *
     * @return void
     */
    protected function defineRouteBindings()
    {

    }

    /**
     * Define the resources for this package.
     *
     * @return void
     */
    protected function defineResources()
    {
        $this->loadViewsFrom(CORE_PATH . '/resources/views', 'core');
        $this->loadTranslationsFrom(CORE_PATH . '/resources/lang', 'core');
    }

    /**
     * Register the other components included in the components
     * folder. Needs to contain a 'provides.php' array which
     * lets us know which providers we are to be included
     *
     * @return void
     */
    protected function registerComponents()
    {
        $path = realpath(CORE_PATH . '/../');

        collect(glob("{$path}/*/provides.php"))
            ->map(
                function ($file) {
                    return include$file;
                }
            )
            ->flatten()
            ->filter(
                function ($class) {
                    return class_exists($class);
                }
            )->each(
                function ($class) {
                        $this->app->register($class);
                }
            );
    }

    protected function definePublished()
    {
        $this->publishes([
            __DIR__ . '/../../config/core.php' => config_path('core.php')
        ], 'config');

        $this->publishes([
            __DIR__ . '/../../database/migrations/' => database_path('migrations')
        ], 'migrations');
    }
}

==> mtc-core-v0.2.5-7a70a3.tar: src/Providers/CoreServiceProvider.php <==
<?php
/**
 * Core Service Provider
 *
 * PHP Version 7
 *
 * @category Mtc\Core\Providers
 * @package  Mtc\Core\Admin
 * @author   Craig McCreath <craig.mccreath@mtcmedia.co.uk>
 */

namespace Mtc\Core\Providers;

use App;
use Cache;
use Event;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\ServiceProvider;
use Mtc\Core\Node;
use Mtc\Core\Core;
use Mtc\Core\Http\ViewComposers\EntrustComposer;
use Mtc\Core\Listeners\DeleteCustomData;
use Mtc\Core\Listeners\DeleteNode;
use Mtc\Core\Listeners\SaveCustomData;
use Mtc\Core\Listeners\ValidateMtcLogin;
use View;

/**
 * Connect Core to Laravel, registering routes and services that require access.
 *
 * @category Mtc\Core\Providers
 * @package  Mtc\Core\Admin
 * @author   Craig McCreath <craig.mccreath@mtcmedia.co.uk>
 */
class CoreServiceProvider extends ServiceProvider
{
    /**
     * Boot the service provider.
     *
     * @return void
     */
    public function boot()
    {
        $this->defineRoutes();
        $this->defineResources();
        $this->definePublished();

        // Define a custom 'transpose' macro for Collections.
        Collection::macro(
            'transpose', function () {
                $items = array_map(
                    function (...$items) {
                        return $items;
                    }, ...$this->values()
                );

                return new static($items);
            }
        );
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        if (! defined('CORE_PATH')) {
            define('CORE_PATH', realpath(__DIR__.'/../../'));
        }

        if (! class_exists('Core')) {
            class_alias(Core::class, 'Core');
        }

        if ($this->app->runningInConsole()) {
            $this->commands([]);
        }

        // Register the Laravel debug bar when not production
        if ($this->app->environment('production') === false) {
            $this->app->register('Barryvdh\Debugbar\ServiceProvider');
        }

        $this->registerComponents();
    }

    /**
     * Define the routes.
     *
     * @return void
     */
    protected function defineRoutes()
    {
        $this->defineRouteBindings();

        /**
         * If the routes have not been cached, we will include them in a route group
         * so that all of the routes will be conveniently registered to the given
         * controller namespace. After that we will load the Core routes file.
         */
        if (! $this->app->routesAreCached()) {
            Route::group(
                ['namespace' => 'Mtc\Core\Http\Controllers'],
                function ($router) {
                    $path = realpath(CORE_PATH . '/routes');
                    foreach (glob("{$path}/*.php") as $file) {
                        include $file;
                    }
                }
            );
        }
    }

    /**
     * Define the route model bindings.
     *
     * @return void
     */
    protected function defineRouteBindings()
    {

    }

    /**
     * Define the resources for this package.
     *
     * @return void
     */
    protected function defineResources()
    {
        $this->loadViewsFrom(CORE_PATH . '/resources/views', 'core');
        $this->loadTranslationsFrom(CORE_PATH . '/resources/lang', 'core');
    }

    /**
     * Register the other components included in the components
     * folder. Needs to contain a 'provides.php' array which
     * lets us know which providers we are to be included
     *
     * @return void
     */
    protected function registerComponents()
    {
        $path       = realpath(CORE_PATH . '/../');
        $components = realpath($this->app->basePath() . '/components');

        collect(glob("{$path}/*/provides.php"))
            ->merge(glob("{$components}/*/provides.php"))
            ->map(
                function ($file) {
                    return include $file;
                }
            )
            ->flatten()
            ->filter(
                function ($class) {
                    return class_exists($class);
                }
            )->each(
                function ($class) {
                    $this->app->register($class);
                }
            );
    }

    protected function definePublished()
    {
        $this->publishes([
            __DIR__ . '/../../config/core.php' => config_path('core.php')
        ], 'config');

        $this->publishes([
            __DIR__ . '/../../database/migrations/' => database_path('migrations')
        ], 'migrations');
    }
}
